Merge pull request #444 from aaronenyeshi/vg20-initial

initial gfx906 support

[ROCm/hip commit: 67d45164fa]
Tá an tiomantas seo le fáil i:
Maneesh Gupta
2018-05-18 13:18:07 +05:30
tiomanta ag GitHub
tuismitheoir 183fce6294 9a591d6c26
tiomantas 3da5fac84b
D'athraigh 7 comhad le 30 breiseanna agus 9 scriosta
@@ -29,7 +29,7 @@ THE SOFTWARE.
#include "hip/hip_runtime.h"
#include "test_common.h"
#if __HIP_ARCH_GFX803__ || __HIP_ARCH_GFX900__
#if __HIP_ARCH_GFX803__ || __HIP_ARCH_GFX900__ || __HIP_ARCH_GFX906__
__global__ void kernel_abs_int64(hipLaunchParm lp, long long *input, long long *output) {
int tx = threadIdx.x;
+1 -1
Féach ar an gComhad
@@ -32,7 +32,7 @@ THE SOFTWARE.
#define HALF_SIZE 64 * sizeof(__half)
#define HALF2_SIZE 64 * sizeof(__half2)
#if __HIP_ARCH_GFX803__ || __HIP_ARCH_GFX900__
#if __HIP_ARCH_GFX803__ || __HIP_ARCH_GFX900__ || __HIP_ARCH_GFX906__
__global__ void __halfMath(hipLaunchParm lp, __half* A, __half* B, __half* C) {
int tx = threadIdx.x;